# Passeo
<div style="text-align: center; display: grid; justify-content: center;"><img style="margin: auto; margin-bottom: 1rem; border-radius: 30%;" height="150" width="150" src="https://raw.githubusercontent.com/ArjunSharda/Passeo/main/ext/passeo.jpg"/></div>

"🔓 Generate a Password with multiple options"

# What is Passeo?

Passeo is a python password generator developed by [Arjun Sharda](https://github.com/ArjunSharda), under the [MIT License](https://github.com/ArjunSharda/Passeo/blob/main/LICENSE).


# Why use Passeo?

Passeo is a upcoming password generator project, with massive plans in the future, such as generation of a password and strength checker via terminal. Passeo is also completely safe to use and is open source for the community to know that and learn from how the password generator.


-----------------

# Quickstart

```python
from passeo import passeo
print(passeo().generate(10, numbers=True, symbols=True, save=True))
```

# v1.0.4 changes
- [ADDED] Added case check to the strength check to Passeo, checking for uppercase/lowercase, and did some other minor improvements. See the Pull Request [here](https://github.com/ArjunSharda/Passeo/pull/1/files).


<hr>
<h6 align="center">© Arjun Sharda 2022 
<br>
All Rights Reserved</h6>
